//
// VPNUAccountStatus.h
// VPNUnlimitedSDK
//
// Copyright (c) 2019 KeepSolid. All rights reserved.
//

//
// Use of this SDK is subject to the VPN Unlimited SDK License Agreement
// https://www.keepsolid.com/static/docs/VPN_Unlimited_SDK_License.html
//

#import <CoreLocation/CLLocation.h>
#import <VPNUnlimitedSDK/VPNUManager.h>

/*!
 @header
 @abstract Header file
 */

@class VPNULocation;

/*!
@interface VPNUAccountStatus
@abstract A model object which describes user's account status.
*/
@interface VPNUAccountStatus : NSObject <NSCoding>
/*!
 @brief Real location information.
 */
@property (readonly) VPNULocation *real;
/*!
 @brief Server location information.
 */
@property (readonly) VPNULocation *server;
/*!
 @brief Default protocol based on contents of `@link availableProtocols@/link` field.
 */
@property (readonly) VPNUProtocol defaultProtocol;
/*!
 @brief Array of strings describing available VPN protocols for current user.
 */
@property (strong, readonly) NSArray* availableProtocols;
/*!
 @brief A date of current account expiration.
 */
@property (strong, readonly) NSDate *expiredDate;
/*!
 @brief Number of seconds left till account expiration.
 */
@property (readonly) long long secondsLeft;
/*!
 @brief A human-readable string which describes the time left till account expiration.
 */
@property (copy, readonly) NSString *timeLeftString;
/*!
 @brief A boolean value which indicates if account has lifetime subscription.
 */
@property (readonly, getter=isLifetime) BOOL lifetime;
/*!
 @brief A boolean value which indicates if the account in trial period.
 */
@property (readonly, getter=isTrialPeriod) BOOL trialPeriod;
/*!
 @brief A boolean value which indicates if the account is expired.
 */
@property (readonly, getter=isExpired) BOOL expired;

@end
