//
//  VPNUAccountUserInfo.h
//  VPNUnlimitedSDK
//
//  Copyright (c) 2015 KeepSolid. All rights reserved.
//

//
// Use of this SDK is subject to the VPN Unlimited SDK License Agreement
// https://www.keepsolid.com/static/docs/VPN_Unlimited_SDK_License.html
//

/*!
 @header
 @abstract Header file
 */


#import <Foundation/Foundation.h>

/*!
 @class VPNUAccountUserInfo
 @abstract
 A model object which describes user's account information.
 */
@interface VPNUAccountUserInfo : NSObject <NSCoding>
/*!
 @brief accessToken.
 */
@property (copy, nonatomic, nullable) NSString *accessToken;
/*!
 @brief refreshToken.
 */
@property (copy, nonatomic, nullable) NSString *refreshToken;
/*!
 @brief A boolean value which indicates if account is confirmed.
 */
@property (readonly) BOOL isConfirmed;
/*!
 @brief A boolean value which indicates if account is guest(fake).
 */
@property (readonly) BOOL isGuest;
/*!
 @brief Date registration
 */
@property (nonatomic, readonly, nullable) NSDate *registrationDate;
/*!
 @brief User's account ID
 */
@property (readonly) NSInteger userID;
/*!
 @brief Username (usually an email).
 */
@property (nonatomic, readonly, nullable) NSString *username;
/*!
 @brief Autologin URL.
 */
@property (nonatomic, readonly, nullable) NSString *autologinURI;
/*!
 @brief Initializes and returns a newly allocated account info object with the specified dictionary object.
 @param dictionary The dictionary object for internal usage.
 @return An initialized account info object or nil if the object couldn't be created.
 */
- (nonnull instancetype)initWithDictionary:(nullable NSDictionary *)dictionary NS_DESIGNATED_INITIALIZER;

@end

