//
//  VPNUAuthDelegate.h
//  VPNUnlimitedSDK
//
//  Copyright (c) 2015 KeepSolid. All rights reserved.
//

//
// Use of this SDK is subject to the VPN Unlimited SDK License Agreement
// https://www.keepsolid.com/static/docs/VPN_Unlimited_SDK_License.html
//

/*!
 @header
 @abstract Header file
 */

#import <Foundation/Foundation.h>
#import <VPNUnlimitedSDK/VPNUSocialServiceType.h>
#import <VPNUnlimitedSDK/VPNUTwoFactorResponse.h>
#import <VPNUnlimitedSDK/VPNUTwoFactorAuth.h>


typedef void (^VPNUAuthDelegateCompletionHandler)(NSString *credentials);

/*!
 @protocol VPNUAuthDelegate
 @abstract
 Protocol for implementing custom authorization.
 @discussion
 If you use custom authorization routines (like Facebook or Google Plus), you implement methods by this protocol to provide the results of this authorization. First you must return YES in @link willImplementCustomAuthorization@/link method. Then, when @link resolveCustomAuthorizationWithCompletion:@/link is called, you finish the authorization routine and call the authorization completion handler with appropriate parameters.
 <pre>@textblock
 - (BOOL)willImplementCustomAuthorization {
     return _authType == authTypeSocial;
 }
 
 - (void)resolveCustomAuthorizationWithCompletion:(void(^)(VPNUSocialServiceType type, NSString *accessToken, NSString *tokenID))completion {
     completionHandler(oauthJsonString);
 }
 @/textblock</pre>
 */
@protocol VPNUAuthDelegate <NSObject>
@required
/*!
 @brief Method returns YES if custom authorization
 @return YES - Custom Authorization
 */
- (BOOL)willImplementCustomAuthorization;
/*!
 @brief Resolving custom authorization
 @param completion Completion block.
 */
- (void)resolveCustomAuthorizationWithCompletion:(void(^)(VPNUSocialServiceType type,
                                                          NSString *accessToken,
                                                          NSString *tokenID,
                                                          NSString *refreshToken))completion;

@optional

- (void)resolveTwoFactorAuth:(VPNUTwoFactorAuth *)twoFactorAuth
              withCompletion:(void (^)(VPNUTwoFactorResponse *response))completion;

- (void)updateTwoFactorAuth:(VPNUTwoFactorAuth *)twoFactorAuth;

- (void)cantRecoverAuthorizationNeedLogout;

@end
