//
//  VPNUConnection.h
//  VPNUnlimitedSDK
//
//  Copyright © 2018 KeepSolid. All rights reserved.
//

//
// Use of this SDK is subject to the VPN Unlimited SDK License Agreement
// https://www.keepsolid.com/static/docs/VPN_Unlimited_SDK_License.html
//


#import <VPNUnlimitedSDK/VPNUManager.h>

/*!
 @header
 @abstract Header file
 */

/*! @const VPNUConnectionStatusDidChangeNotification Notification that is posted when the VPN connection status changes. */
extern NSString * const VPNUConnectionStatusDidChangeNotification;
/*! @const VPNUConnectionStatusUserInfoKey Value for this key in `userInfo` dictionary contains `NSNumber` representation of `@link VPNUConnectionStatus@/link`. */
extern NSString * const VPNUConnectionStatusUserInfoKey;


/*!
 * @enum VPNUConnectionStatus
 * @abstract VPN status codes
 */
typedef enum {
    /*! @const VPNUConnectionStatusInvalid The VPN is not configured. */
    VPNUConnectionStatusInvalid,
    /*! @const VPNUConnectionStatusDisconnected The VPN is disconnected. */
    VPNUConnectionStatusDisconnected,
    /*! @const VPNUConnectionStatusConnecting The VPN is connecting. */
    VPNUConnectionStatusConnecting,
    /*! @const VPNUConnectionStatusConnected The VPN is connected. */
    VPNUConnectionStatusConnected,
    /*! @const VPNUConnectionStatusReasserting The VPN is reconnecting following loss of underlying network connectivity. */
    VPNUConnectionStatusReasserting,
    /*! @const VPNUConnectionStatusDisconnecting The VPN is disconnecting. */
    VPNUConnectionStatusDisconnecting
} VPNUConnectionStatus;

/*!
 @class VPNUConnection
 @abstract Connection info, status & connected date
 */
@interface VPNUConnection : NSObject

/*!
* @property status
* @discussion The current status of the VPN connection. This value is KVO-compliant.
*/
@property (readonly) VPNUConnectionStatus status;

/*!
 * @property connectedDate
 * @discussion The date and time when the connection status changed to NEVPNStatusConnected. This property is nil if the connection is not fully established.
 */
@property (readonly) NSDate *connectedDate;

@property (readonly) NSString *lastIpAddress;


+ (NSString *)protocolStringFromProtocol:(VPNUProtocol)protocol;

@end
