//
//  VPNULocationInfo.h
//  VPNUnlimitedSDK
//
//  Copyright © 2018 KeepSolid. All rights reserved.
//

#import <Foundation/Foundation.h>
#import <CoreLocation/CLLocation.h>

/*!
 @header
 @abstract Header file
 */

/*!
@class VPNULocationInfo
@brief A model object which describes a user's geolocation.
*/
@interface VPNULocationInfo : NSObject

/*!
 @brief Country.
 */
@property (copy, readonly) NSString *country;
/*!
 @brief City.
 */
@property (copy, readonly) NSString *city;
/*!
 @brief URL of country's flag image.
 */
@property (copy, readonly) NSString *flagURI;
/*!
 @brief URL of country's flat flag image.
 */
@property (copy, readonly) NSString *flatFlagURI;
/*!
 @brief URL of country's flag bigger image.
 */
@property (copy, readonly) NSString *flagHDURI;
/*!
 @brief Returns current IP address.
 */
@property (copy, readonly) NSString *serverIP;
/*!
 @brief A boolean value which indicates if VPN connection is active.
 */
@property (readonly, getter=isVpnActive) BOOL vpnActive;
/*!
 @brief Returns region.
 */
@property (copy, readonly) NSString *region;
/*!
 @brief Returns region description.
 */
@property (copy, readonly) NSString *regionDescription;
/*!
 @brief Returns region name.
 */
@property (copy, readonly) NSString *regionName;

/*!
 @brief A structure that contains a user's geographical coordinate.
 */
@property (nonatomic, readonly) CLLocationCoordinate2D coordinates;

@end
