//
//  VPNUManager.h
//  VPNUnlimitedSDK
//
//  Copyright © 2018 KeepSolid. All rights reserved.
//

//
// Use of this SDK is subject to the VPN Unlimited SDK License Agreement
// https://www.keepsolid.com/static/docs/VPN_Unlimited_SDK_License.html
//

#import <NetworkExtension/NetworkExtension.h>

/*!
@header
@abstract Header file
*/

/*! @const VPNUNewSSIDFoundNotification Notification that is posted when device connects to a new unrecognized WiFi network. */
extern NSString * const VPNUNewSSIDFoundNotification;

/*! @const kVPNUNewSSIDNotificationKey Key for newly found SSID value, passed in userInfo dictionary of @link VPNUNewSSIDFoundNotification@/link notification. */
extern NSString * const kVPNUNewSSIDNotificationKey;


/*!
 @enum VPNUProtocol
 @abstract VPN protocol used by configurator.
 */
typedef enum {
    /*! @const VPNUProtocolUnknown Protocol is not defined. */
    VPNUProtocolUnknown = 0,
    /*! @const VPNUProtocolIPSecIKEv2 IPSec IKEv2 is used. */
    VPNUProtocolIPSecIKEv2 = 2,
    /*! @const VPNUProtocolOpenVPN OpenVPN is used. */
    VPNUProtocolOpenVPN = 4,
    /*! @const VPNUProtocolKeepSolidWiseTCP Patched OpenVPN with TCP port is used. */
    VPNUProtocolKeepSolidWiseTCP = 6,
    /*! @const VPNUProtocolKeepSolidWiseUDP Patched OpenVPN with UDP port is used. */
    VPNUProtocolKeepSolidWiseUDP = 7,
    /*! @const VPNUProtocolWireguard Wireguard is used. */
    VPNUProtocolWireguard = 8,
} VPNUProtocol;


/*!
 @class VPNUManager
 @abstract Manager for protocol configuration
 */
@interface VPNUManager : NSObject

/*!
 @brief Protocol used when downloading and configuring VPN profile.
 @discussion Set this property before calling @link startVPNTunnelWithServerItem:protocol:completion:@/link method. Default value is @link VPNUProtocolIPSecIKEv2@/link.
 */
@property (nonatomic, readonly) VPNUProtocol protocol;

/*!
 @brief Custom name for a downloaded VPN profile if Wise or OpenVPN is selected as protocol.
 @discussion If not set - `profileName` is used.
 */
@property (nonatomic, copy) NSString *customProtocolProfileName;

@end
