//
//  VPNUResponseContainer.h
//  VPNUnlimitedSDK
//
//  Created by A. Gordiyenko on 3/31/15.
//  Copyright (c) 2015 KeepSolid. All rights reserved.
//

#import <Foundation/Foundation.h>

/*!
 @header VPNUResponseCode
 @abstract Header file
 */

/*!
 * @typedef VPNUResponseCode
 * @brief Response codes.
 */
typedef enum {
    /*! @const VPNUResponseCodeOperationSuccess Operation success. */
    VPNUResponseCodeOperationSuccess = 200,
    
    /*! @const VPNUResponseCodeAlreadyConfirmed Already Confirmed. */
    VPNUResponseCodeAlreadyConfirmed = 301,
    /*! @const VPNUResponseCodeInvalidUserNameOrPassword Invalid user name or password. */
    VPNUResponseCodeInvalidUserNameOrPassword = 302,
    /*! @const VPNUResponseCodeAccountHasBeenBlocked Entered password incorrectly 5 times and your account has been blocked. */
    VPNUResponseCodeAccountHasBeenBlocked = 303,
    /*! @const VPNUResponseCodeInvalidReferenceCode Invalid reference code. */
    VPNUResponseCodeInvalidReferenceCode = 304,
    /*! @const VPNUResponseCodeErrorWhileEncryption Error while encryption. */
    VPNUResponseCodeErrorWhileEncryption = 305,
    /*! @const VPNUResponseCodeErrorInvalidURLForProfile Invalid URL for profile. */
    VPNUResponseCodeErrorInvalidURLForProfile = 306,
    /*! @const VPNUResponseCodeToManyUsersRegisteredFromThisDevice Too many users have been registered from this device. */
    VPNUResponseCodeToManyUsersRegisteredFromThisDevice = 308,
    /*! @const VPNUResponseCodeTooManyDevices More than N devices registered for same account. */
    VPNUResponseCodeTooManyDevices = 309,
    /*! @const VPNUResponseCodeUserAlreadyExist This email is already in use. */
    VPNUResponseCodeUserAlreadyExist = 310,
    /*! @const VPNUResponseCodeNeedConfirmEmail You should confirm your e-mail. */
    VPNUResponseCodeNeedConfirmEmail = 311,
    /*! @const VPNUResponseCodePasswordSecurityCheckFailed Password security check failed. */
    VPNUResponseCodePasswordSecurityCheckFailed = 312,
    /*! @const VPNUResponseCodeUserBanned This account is banned. */
    VPNUResponseCodeUserBanned = 313,
    /*! @const VPNUResponseCodeUserDeleted Account suspended. */
    VPNUResponseCodeUserDeleted = 314,
    /*! @const VPNUResponseCodeServiceAccessDenied Service access denied. */
    VPNUResponseCodeServiceAccessDenied = 318,
    /*! @const VPNUResponseCodeErrorSignIn Sign In Error. */
    VPNUResponseCodeErrorSignIn = 321,
    /*! @const VPNUResponseCodeErrorInvalidSignInToken Invalid Sign In token. */
    VPNUResponseCodeErrorInvalidSignInToken = 322,
    /*! @const VPNUResponseCodeAccountCantBeUsed This email has been already used for login. */
    VPNUResponseCodeAccountCantBeUsed = 323,
    /*! @const VPNUResponseCodeEndpontInactive The selected entry point is not active. */
    VPNUResponseCodeEndpontInactive = 324,
    /*! @const VPNUResponseCodeProfileIsIncorrect Social login failed. */
    VPNUResponseCodeProfileIsIncorrect = 327,
    /*! @const VPNUResponseCodePurchaseAlreadyExists Purchase already exists on server DB. */
    VPNUResponseCodePurchaseAlreadyExists = 341,
    /*! @const VPNUResponseCodeErrorAppleResponsePurchase Apple not respond for purchase validation. */
    VPNUResponseCodeErrorAppleResponsePurchase = 342,
    /*! @const VPNUResponseCodeErrorInvalidPurchase Purchase is invalid. Hash for purchase already exist for example. */
    VPNUResponseCodeErrorInvalidPurchase = 343,
    /*! @const VPNUResponseCodeRedeemAlreadyUsed Redeem already used. */
    VPNUResponseCodeRedeemAlreadyUsed = 351,
    /*! @const VPNUResponseCodeRedeemTypeAlreadyUsed Redeem with this type already used. */
    VPNUResponseCodeRedeemTypeAlreadyUsed = 352,
    /*! @const VPNUResponseCodeInvitesLimitExceeded You have exceeded the limit of invitations. */
    VPNUResponseCodeInvitesLimitExceeded = 355,
    /*! @const VPNUResponseCodeTooMuchMail Too many mails was sent (by password recovery for example). */
    VPNUResponseCodeTooMuchMail = 361,
    
    /*! @const VPNUResponseCodeErrorGeneral Some general error. */
    VPNUResponseCodeErrorGeneral = 500,
    /*! @const VPNUResponseCodeErrorInvalidRequest Invalid request. */
    VPNUResponseCodeErrorInvalidRequest = 501,
    /*! @const VPNUResponseCodeErrorInvalidParams Invalid params on request. */
    VPNUResponseCodeErrorInvalidParams = 502,
    /*! @const VPNUResponseCodeErrorSessionSoured Session soured. */
    VPNUResponseCodeErrorSessionSoured = 503,
    /*! @const VPNUResponseCodeErrorInvalidEmailFormat Invalid e-mail domain or/and email format. */
    VPNUResponseCodeErrorInvalidEmailFormat = 504,
    /*! @const VPNUResponseCodeErrorServerDBLayer Error on server DB layer. */
    VPNUResponseCodeErrorServerDBLayer = 505,
    /*! @const VPNUResponseCodeErrorTwoFactorAuthenticationNeed Need resolve two factor authentication. */
    VPNUResponseCodeErrorTwoFactorAuthenticationNeed = 603,
    /*! @const VPNUResponseCodeErrorInvalidTwoFactorAuthenticationToken Invalid two factor authentication token. */
    VPNUResponseCodeErrorInvalidTwoFactorAuthenticationToken = 604,
    /*! @const VPNUResponseCodeErrorInvalidTwoFactorAuthenticationRecoveryKey Invalid two factor authentication recovery key. */
    VPNUResponseCodeErrorInvalidTwoFactorAuthenticationBackupCode = 606,
    /*! @const VPNUResponseCodeErrorTwoFactorAuthenticationExceedMaxAttempts User exceed max attempts for this two factor authentication type. */
    VPNUResponseCodeErrorTwoFactorAuthenticationExceedMaxAttempts = 607,
    /*! @const VPNUResponseCodeErrorTwoFactorAuthenticationTooManyMails Too many mails was sent with two factor code. */
    VPNUResponseCodeErrorTwoFactorAuthenticationTooManyMails = 608,
    /*! @const VPNUResponseCodeErrorTwoFactorAuthenticationExpiredToken  Expired two factor authentication token. */
    VPNUResponseCodeErrorTwoFactorAuthenticationExpiredToken = 611,

} VPNUResponseCode;


/*!
 @class VPNUResponseContainer
 @brief Localized error codes
 */
@interface VPNUResponseContainer : NSObject


/*!
 @brief Localizing response code.
 @param responseCode Response code.
 @return Localized string;
 */
+ (NSString *)localizedStringFromResponse:(NSInteger)responseCode;

@end
