//
//  VPNUServerItem.h
//  VPNUnlimitedSDK
//
//  Copyright (c) 2015 KeepSolid. All rights reserved.
//

//
// Use of this SDK is subject to the VPN Unlimited SDK License Agreement
// https://www.keepsolid.com/static/docs/VPN_Unlimited_SDK_License.html
//

/*!
 @header
 @abstract Header file
 */


#import <CoreLocation/CoreLocation.h>
#import <Foundation/Foundation.h>

typedef NS_ENUM(NSUInteger, VPNUServerStatus) {
    VPNUServerStatusPurchased,
    VPNUServerStatusDeploy,
    VPNUServerStatusReady
};

/*!
 @class VPNUServerItem
 @abstract
 A model object which describes a VPN server.
 */
@interface VPNUServerItem : NSObject <NSCoding>
/*!
 @brief Server's name.
 */
@property (nonatomic, readonly) NSString *name;
/*!
 @brief Server's description.
 */
@property (nonatomic, readonly) NSString *shortDescription;
/*!
 @brief A concatenation of name and shortDescription properties.
 */
@property (nonatomic, readonly) NSString *fullDescription;
/*!
 @brief The region shorthand description.
 */
@property (nonatomic, readonly) NSString *region;
/*!
 @brief URI of region country's flag image.
 */
@property (nonatomic, readonly) NSString *flagURI;
/*!
 @brief Name of icon country's flag image.
 */
@property (nonatomic, readonly) NSString *iconName;
/*!
 @brief A structure that contains a server's geographical coordinate.
 */
@property (nonatomic, readonly) CLLocationCoordinate2D coordinates;
/*!
 @brief Server's priority.
 */
@property (nonatomic, readonly) NSInteger priority;
/*!
 @brief Server's network load.
 */
@property (nonatomic, readonly) double networkLoad;
/*!
 @brief Server is restricted from P2P usage.
 */
@property (nonatomic, readonly, getter=isP2PAllowed) BOOL P2PAllowed;

/*!
 @brief Server/IP is personal.
 */
@property (readonly) BOOL isPersonal;

/*!
 @brief Status of personal server deployment.
 */
@property (readonly) VPNUServerStatus personalServerStatus;

/*!
 @brief Stream server URL.
 */
@property (nonatomic, readonly) NSString *streamServerUrl;

- (instancetype)initWithDictionary:(NSDictionary *)info
                         flagsPath:(NSString *)flagsBasePath;

@end
